==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/61/61f68a0dabc8cf16ad7a79153af9e1fe.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ReportBundle/Config/services.php */
class __TwigTemplate_55918641e1c9b8978ed50672c4c6b4c1 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

use Mautic\\CoreBundle\\DependencyInjection\\MauticCoreExtension;
use Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\ContainerConfigurator;

return function (ContainerConfigurator \$configurator): void {
    \$services = \$configurator->services()
        ->defaults()
        ->autowire()
        ->autoconfigure()
        ->public();

    \$excludes = [
        'Generator',
        'Builder/MauticReportBuilder.php',
        'Form/DataTransformer/ReportFilterDataTransformer.php',
        'Scheduler/Entity',
        'Scheduler/Option',
    ];

    \$services->load('Mautic\\\\ReportBundle\\\\', '../')
        ->exclude('../{'.implode(',', array_merge(MauticCoreExtension::DEFAULT_EXCLUDES, \$excludes)).'}');

    \$services->load('Mautic\\\\ReportBundle\\\\Entity\\\\', '../Entity/*Repository.php');

    \$services->alias('mautic.report.model.report', Mautic\\ReportBundle\\Model\\ReportModel::class);
    \$services->alias('mautic.report.model.csv_exporter', Mautic\\ReportBundle\\Model\\CsvExporter::class);
    \$services->alias('mautic.report.model.excel_exporter', Mautic\\ReportBundle\\Model\\ExcelExporter::class);
    \$services->alias('mautic.report.model.report_exporter', Mautic\\ReportBundle\\Model\\ReportExporter::class);
    \$services->alias('mautic.report.model.schedule_model', Mautic\\ReportBundle\\Model\\ScheduleModel::class);
    \$services->alias('mautic.report.model.report_export_options', Mautic\\ReportBundle\\Model\\ReportExportOptions::class);
    \$services->alias('mautic.report.model.report_file_writer', Mautic\\ReportBundle\\Model\\ReportFileWriter::class);
    \$services->alias('mautic.report.model.export_handler', Mautic\\ReportBundle\\Model\\ExportHandler::class);
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ReportBundle/Config/services.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ReportBundle/Config/services.php", "/var/www/html/mauticGIT-Test/app/bundles/ReportBundle/Config/services.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/61/61f68a0dabc8cf16ad7a79153af9e1fe.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ReportBundle/Config/services.php */
class __TwigTemplate_55918641e1c9b8978ed50672c4c6b4c1 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

use Mautic\\CoreBundle\\DependencyInjection\\MauticCoreExtension;
use Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\ContainerConfigurator;

return function (ContainerConfigurator \$configurator): void {
    \$services = \$configurator->services()
        ->defaults()
        ->autowire()
        ->autoconfigure()
        ->public();

    \$excludes = [
        'Generator',
        'Builder/MauticReportBuilder.php',
        'Form/DataTransformer/ReportFilterDataTransformer.php',
        'Scheduler/Entity',
        'Scheduler/Option',
    ];

    \$services->load('Mautic\\\\ReportBundle\\\\', '../')
        ->exclude('../{'.implode(',', array_merge(MauticCoreExtension::DEFAULT_EXCLUDES, \$excludes)).'}');

    \$services->load('Mautic\\\\ReportBundle\\\\Entity\\\\', '../Entity/*Repository.php');

    \$services->alias('mautic.report.model.report', Mautic\\ReportBundle\\Model\\ReportModel::class);
    \$services->alias('mautic.report.model.csv_exporter', Mautic\\ReportBundle\\Model\\CsvExporter::class);
    \$services->alias('mautic.report.model.excel_exporter', Mautic\\ReportBundle\\Model\\ExcelExporter::class);
    \$services->alias('mautic.report.model.report_exporter', Mautic\\ReportBundle\\Model\\ReportExporter::class);
    \$services->alias('mautic.report.model.schedule_model', Mautic\\ReportBundle\\Model\\ScheduleModel::class);
    \$services->alias('mautic.report.model.report_export_options', Mautic\\ReportBundle\\Model\\ReportExportOptions::class);
    \$services->alias('mautic.report.model.report_file_writer', Mautic\\ReportBundle\\Model\\ReportFileWriter::class);
    \$services->alias('mautic.report.model.export_handler', Mautic\\ReportBundle\\Model\\ExportHandler::class);
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ReportBundle/Config/services.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ReportBundle/Config/services.php", "/var/www/html/production-demo/app/bundles/ReportBundle/Config/services.php");
    }
}
